@@ -228,7 +228,11 @@ class Structure:
         )
 
     def to_rdkit(self, charge: Optional[int] = 0) -> rdkit.Chem.rdchem.Mol:
-        return mtr.xyz2mol(self.atomic_numbers, charge, self.atomic_positions.T)
+        return mtr.xyz2mol(
+            self.atomic_numbers,
+            charge,
+            self.atomic_positions.T.convert(mtr.angstrom).value,
+        )
 
     @property
     def num_atoms(self) -> int:
@@ -492,7 +496,7 @@ def _structure_from_identifier(
 ) -> mtr.Structure:
     # for motivation on generating 25 (as opposed to, say, 10 or 100) conformers, see:
     # https://github.com/rdkit/UGM_2015/blob/master/Presentations/ETKDG.SereinaRiniker.pdf
-
+    rdkit.RDLogger.DisableLog("rdApp.*")
     if smiles is not None:
         mol = rdkit.Chem.MolFromSmiles(smiles, sanitize=False)
     elif inchi is not None:
